;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "lsp-mode" "20251118.1616"
  "LSP mode."
  '((emacs         "28.1")
    (dash          "2.18.0")
    (f             "0.20.0")
    (ht            "2.3")
    (spinner       "1.7.3")
    (markdown-mode "2.3")
    (lv            "0")
    (eldoc         "1.11"))
  :url "https://github.com/emacs-lsp/lsp-mode"
  :commit "6f9e3eed899ebc4eae670168d4b13fd1e143ef7f"
  :revdesc "6f9e3eed899e"
  :keywords '("languages"))
